# Contributing

<p align="center">
<a href="#best-practices">Best practices</a> ·
<a href="#pull-request-process">Pull request process</a> ·
<a href="#code-of-conduct">Code of conduct</a>
</p>

First of all, thanks for taking the time to contribute!

This file includes best practices and guidelines for contributing to our
project. We encourage you to follow them and help us create a better product!

## Best practices

- We follow a [code of conduct](#code-of-conduct), review it and honor it in all
  your interactions with the project.
- When contributing to this repository, first create an issue to explain the
  change you want to make.
  - The issues will be preferably written in English, although Spanish is
    also acceptable.
  - The issue title should briefly summarize the proposal.
  - The issue body should include a description of the proposal with all the
    details, conditions, dependencies affected, charts, screenshots, etc.,
    that can help to further understand and evaluate the proposal.
- Create a new branch before making any change in the repository. This branch
  should follow this format: issue_ID-and-summary (for example,
  23-add-new-provider).
- Create commit messages that briefly describe the change applied, preferably in
  English.

## Pull request process

1. Ensure any install or build dependencies are solved before doing a build.
2. Update the README.md file with details of the changes. This includes new
   environment variables, exposed ports, useful file locations and container
   parameters.
3. Increase the version number in any package.json files to the new
   version that this pull request would represent. The versioning scheme we
   follow is [SemVer](http://semver.org/).
4. You may squash and merge the pull request once you have the sign-off of two
   other developers. If you do not have permission to merge, you may request the
   second reviewer to merge the pull request for you.

## Code of conduct

### Our pledge

In the interest of fostering an open and welcoming environment, we as
contributors and maintainers pledge to make participation in our project and our
community a harassment-free experience for everyone, regardless of age, body
size, disability, ethnicity, gender identity and expression, level of
experience, nationality, personal appearance, race, religion, or sexual identity
and orientation.

### Our standards

Examples of behavior that contribute to creating a positive environment include:

- Using welcoming and inclusive language
- Being respectful of differing viewpoints and experiences
- Gracefully accepting constructive criticism
- Focusing on what is best for the community
- Showing empathy towards other community members

Examples of unacceptable behavior by participants include:

- The use of sexualized language or imagery and unwelcome sexual attention or
  advances
- Trolling, insulting/derogatory comments, and personal or political attacks
- Public or private harassment
- Publishing others' private information, such as a physical or electronic
  address, without explicit permission
- Other conduct which could reasonably be considered inappropriate in a
  professional setting

### Our responsibilities

Project maintainers are responsible for clarifying the standards of acceptable
behavior and are expected to take appropriate and fair corrective action in
response to any instances of unacceptable behavior.

Project maintainers have the right and responsibility to remove, edit, or reject
comments, commits, code, wiki edits, issues, and other contributions that do not
comply with this Code of Conduct, or to ban temporarily or permanently any
contributor due to other behaviors that they deem inappropriate, threatening,
offensive, or harmful.

### Scope

This Code of conduct applies both within project spaces and in public spaces
when an individual represents the project or its community. Examples of
representing a project or community include using an official project email
address, posting via an official social media account, or acting as an appointed
representative at an online or offline event. Representation of a project may be
further defined and clarified by project maintainers.

### Enforcement

You can report incidents related to abusive, harassing, or otherwise
unacceptable behavior by contacting the project team
at [info@coru.net](mailto:info@coru.net). All complaints will be reviewed and
investigated and will result in a response that is deemed necessary and
appropriate to the circumstances. The project team is obligated to maintain
confidentiality concerning the reporter of an incident. Further details of
specific enforcement policies may be posted separately.

Project maintainers who do not follow or enforce the Code of conduct in good
faith may face temporary or permanent repercussions as determined by other
members of the project's leadership.

### Attribution

This Code of conduct has been adapted from the [Contributor Covenant][homepage],
version 1.4, available at [http://contributor-covenant.org/version/1/4][version]
.

[homepage]: http://contributor-covenant.org
[version]: http://contributor-covenant.org/version/1/4/
